@@ -6,10 +6,11 @@ from attrdict import AttrDict
 DEFAULTS = {
     'DEFAULT_THROTTLING_VALIDATORS_PATH': 'security.default_validators',
     'THROTTLING_FAILURE_VIEW': 'security.views.throttling_failure_view',
-    'LOG_IGNORE_IP': [],
+    'LOG_REQUEST_IGNORE_IP': (),
+    'LOG_REQUEST_IGNORE_URL_PATHS': (),
     'LOG_REQUEST_BODY_LENGTH': 1000,
     'LOG_RESPONSE_BODY_LENGTH': 1000,
-    'LOG_RESPONSE_BODY_CONTENT_TYPES':  (
+    'LOG_RESPONSE_BODY_CONTENT_TYPES': (
         'application/json', 'application/xml', 'text/xml', 'text/csv', 'text/html', 'application/xhtml+xml'
     ),
     'LOG_JSON_STRING_LENGTH': 250,
@@ -23,6 +24,8 @@ DEFAULTS = {
             r'<password>([^<]*)',
             r'password=([^&]*)',
             r'csrfmiddlewaretoken=([^&]*)',
+            r'(?i)content-disposition: form-data; name="password"\r\n\r\n.*',
+            r'"access_key": "([^"]*)',
         ),
         'HEADERS': (
             r'Authorization',
@@ -30,9 +33,19 @@ DEFAULTS = {
             r'Cookie',
             r'.*token.*',
         ),
+        'QUERIES': (
+            r'.*token.*',
+        ),
     },
     'SENSITIVE_DATA_REPLACEMENT': '[Filtered]',
     'APPEND_SLASH': True,
+    'CELERY_STALE_TASK_TIME_LIMIT_MINUTES': 60,
+    'BACKUP_STORAGE_CLASS': 'security.storages.BackupFileSystemStorage',
+    'BACKUP_STORAGE_PATH': None,
+    'DEBUG_TOOLBAR': False,
+    'SHOW_DEBUG_TOOLBAR': False,
+    'LOG_OUTPUT_REQUESTS': True,
+    'AUTO_GENERATE_TASKS_FOR_DJANGO_COMMANDS': (),
 }
 
 
